An R wrapper to the Python (Cython) spaCy NLP system, from http://spacy.io. Nicely integrated with quanteda. spacyr is designed to provide easy access to the powerful functionality of spaCy, in a simple format.
To use spacyr, you must first have Python and spaCy installed on your system. See the installation instructions from http://github.com/kbenoit/spacyr.
Useful links: