Learn R Programming

spacyr (version 0.9.3)

spacy_finalize: Finalize spaCy

Description

While running the spacy on python through R, a python process is always running in the backgroud and rsession will take up a lot of memory (typically over 1.5GB). spacy_finalize() terminates the Python process and frees up the memory it was using.

Usage

spacy_finalize()

Arguments