powered by
While running the spacy on python through R, a python process is always running in the backgroud and rsession will take up a lot of memory (typically over 1.5GB). spacy_finalize() terminates the Python process and frees up the memory it was using.
spacy_finalize()