Learn R Programming

spacyr (version 0.9.3)

spacy_initialize: Initialize spaCy

Description

Initialize spaCy to call from R.

Usage

spacy_initialize(model = "en", python_executable = NULL, ask = FALSE,
  virtualenv = NULL, condaenv = NULL)

Arguments

model

Language package for loading spacy. Example: en (English) and de (German). Default is en.

python_executable

the full path to the python excutable, for which spaCy is installed

ask

logical; if FALSE, use the first spaCy installation found; if TRUE, list available spaCy installations and prompt the user for which to use. If another (e.g. python_executable) is set, then this value will always be treated as FALSE.

virtualenv

set a path to the python virtual environment with spaCy installed Example: virtualenv = "~/myenv"

condaenv

set a path to the anaconda virtual environment with spaCy installed Example: condalenv = "myenv"