Initialize spaCy to call from R.
spacy_initialize(model = "en", python_executable = NULL, ask = FALSE,
virtualenv = NULL, condaenv = NULL)Language package for loading spacy. Example: en (English) and
de (German). Default is en.
the full path to the python excutable, for which spaCy is installed
logical; if FALSE, use the first spaCy installation found;
if TRUE, list available spaCy installations and prompt the user
for which to use. If another (e.g. python_executable) is set, then
this value will always be treated as FALSE.
set a path to the python virtual environment with spaCy installed
Example: virtualenv = "~/myenv"
set a path to the anaconda virtual environment with spaCy installed
Example: condalenv = "myenv"